@@ -75,21 +75,20 @@ const GIT_VERSION: &str = git_version!(cargo_prefix = "");
     after_help = HELP_TEXT_FOOTER,
     override_usage = r#"
   diff ... | riff [options...]
-  riff [-b] [-w] [options...] <F1> <F2>
+  riff [-b] [-w] [options...] <FD1> <FD2>
   riff [-b] [-w] [options...] --file <FILE>"#
 )]
-
 struct Options {
     /// First file or directory to compare
-    #[arg(requires("f2"))]
-    f1: Option<String>,
+    #[arg(requires("fd2"))]
+    fd1: Option<String>,
 
     /// Second file or directory to compare
     #[arg()]
-    f2: Option<String>,
+    fd2: Option<String>,
 
     /// Read diff or patch file
-    #[arg(long, short, conflicts_with_all = ["f1", "f2"])]
+    #[arg(long, short, conflicts_with_all = ["fd1", "fd2"])]
     file: Option<PathBuf>,
 
     /// Ignore changes in amount of whitespace
@@ -146,7 +145,10 @@ pub(crate) enum UnchangedStyle {
     #[default]
     None,
 
-    /// Try it and report back!
+    /// Old unchanged faint yellow, new unchanged plain yellow
+    Yellow,
+
+    /// Try it and report back! Same as yellow for now.
     Experimental,
 }
 
@@ -236,11 +238,15 @@ fn highlight_diff<W: io::Write + Send + 'static>(
 #[must_use]
 fn try_pager(
     input: &mut dyn io::Read,
-    pager_name: &str,
+    pager_space_separated: &str,
     color: bool,
     formatter: Formatter,
 ) -> bool {
-    let mut command = Command::new(pager_name);
+    let pager_cmdline: Vec<&str> = pager_space_separated.split_whitespace().collect();
+    let mut command = Command::new(pager_cmdline[0]);
+    for arg in pager_cmdline.iter().skip(1) {
+        command.arg(arg);
+    }
 
     if env::var(PAGER_FORKBOMB_STOP).is_ok() {
         // Try preventing fork bombing if $PAGER is set to riff
@@ -496,10 +502,11 @@ fn main() {
 
     let formatter = match options.unchanged_style.unwrap_or(UnchangedStyle::None) {
         UnchangedStyle::None => Formatter::default(),
-        UnchangedStyle::Experimental => Formatter::experimental(),
+        UnchangedStyle::Yellow => Formatter::yellow(),
+        UnchangedStyle::Experimental => Formatter::yellow(),
     };
 
-    if let (Some(file1), Some(file2)) = (options.f1, options.f2) {
+    if let (Some(file1), Some(file2)) = (options.fd1, options.fd2) {
         // "riff file1 file2"
         exec_diff_highlight(
             &file1,
