@@ -117,8 +117,8 @@ impl PlusMinusHeaderHighlighter {
             return highlighted;
         }
 
-        let (mut old_tokens, mut new_tokens, _, _) =
-            to_highlighted_tokens(&self.old_name, &self.new_name, false);
+        let (mut old_tokens, mut new_tokens) =
+            to_highlighted_tokens(&self.old_name, &self.new_name);
 
         brighten_filename(&mut old_tokens);
         brighten_filename(&mut new_tokens);
@@ -230,7 +230,7 @@ mod tests {
             format!(
                 "\
                 {BOLD}--- {INVERSE_VIDEO}{NORMAL_INTENSITY}{OLD}x{NOT_INVERSE_VIDEO}{BOLD}{DEFAULT_COLOR}.txt{NORMAL}\n\
-                {BOLD}+++ {INVERSE_VIDEO}{NORMAL_INTENSITY}{NEW}y{NOT_INVERSE_VIDEO}{BOLD}{DEFAULT_COLOR}.txt{NORMAL}\n"
+                {BOLD}+++ {INVERSE_VIDEO}{NORMAL_INTENSITY}{GREEN}y{NOT_INVERSE_VIDEO}{BOLD}{DEFAULT_COLOR}.txt{NORMAL}\n"
             ),
             highlighted
         );
