@@ -36,7 +36,7 @@ impl Formatter {
         }
     }
 
-    pub(crate) fn experimental() -> Self {
+    pub(crate) fn yellow() -> Self {
         Formatter {
             line_style_old: LineStyle {
                 prefix_style: ANSI_STYLE_NORMAL.with_color(Red),
@@ -112,8 +112,8 @@ impl Formatter {
     fn too_large_to_refine(texts: &[&str]) -> bool {
         let size = texts.iter().map(|text| text.len()).sum::<usize>();
 
-        // This limit used to be higher, but then refining too long on Johan's
-        // laptop. This number is based on very limited experimentation.
+        // This limit used to be higher, but then refining took too long on
+        // Johan's laptop. This number is based on very limited experimentation.
         return size > 300_000usize;
     }
 
@@ -513,7 +513,7 @@ pub(crate) mod tests {
     /// hangs, that's probably what happened again.
     #[test]
     fn test_format_simple_complexity() {
-        // Values from whan this file was added in a single commit:
+        // Values from when this file was added in a single commit:
         // https://github.com/walles/moar/blob/59270d6f8cf454f7a79fcde36a7fcf794768ced9/sample-files/large-git-log-patch.txt
         let lines = 300_000;
         let line_length = 50;
